==> nextcloud-app-calendar-1.5.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/da.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalender",
    "%s has published the calendar \"%s\"" : "%s har offentliggjort kalenderen \"%s\"",
    "Too many redirects. Aborting ..." : "For mange omdirigeringer. Afbryder ...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Serveren gav os ikke adgang til kalenderen (HTTP {%s} fejl)",
    "Error connecting to remote server" : "Fejl ved forbindelse til serveren",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Fejl efter anmodning fra serveren. Dette er muligvis relateret til ikke ens certifikater",
    "Error requesting resource on remote server" : "Fejl efter anmodning fra server",
    "Individual" : "Individuelt",
    "Group" : "Gruppe",
    "Resource" : "Ressource",
    "Room" : "Lokale",
    "Unknown" : "Ukendt",
    "Required" : "Krævet",
    "Optional" : "Valgfri",
    "Does not attend" : "Deltager ikke",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Du er i en ukendt tidszone ({tz}), -sætter tiden til UTC",
    "Please create a calendar first." : "Opret venligst en kalender først",
    "New event" : "Opret begivenhed",
    "CalDAV address for clients" : "CalDAV addresse for klienter",
    "Error saving WebCal-calendar" : "Kunne ikke gemme WebCal-kalender",
    "WebDAV address for subscriptions" : "WeblDAV addresse for abonnementer",
    "EMail has been sent." : "Email afsendt",
    "There was an issue while sending your EMail." : "Der var et problem ved afsendelse af din Email.",
    "group" : "gruppe",
    "Details" : "Detaljer",
    "Attendees" : "Deltagere",
    "Reminders" : "Påmindindelser",
    "Repeating" : "Gentagende",
    "When shared show full event" : "Når delt, vis den fulde begivenhed",
    "When shared show only busy" : "Når delt, vis kun optaget",
    "When shared hide this event" : "Når delt, skjul denne begivenhed",
    "Confirmed" : "Bekræftet",
    "Tentative" : "Foreløbig prøve",
    "Cancelled" : "Annulléret",
    "Please add a title!" : "Vær venlig at tilføje en titel!",
    "Please select a calendar!" : "Vælg venligt kalender",
    "Global" : "Global",
    "None" : "Ingen",
    "Every day" : "Hver dag",
    "Every week" : "Hver uge",
    "Every month" : "Hver måmned",
    "Every year" : "Hvert år",
    "never" : "aldrig",
    "after" : "efter",
    "How about getting started by importing some calendars?" : "Hvad med at starte med at importere nogle kalendere?",
    "At time of event" : "På tidspunktet for begivenheden",
    "5 minutes before" : "5 minutter før",
    "10 minutes before" : "10 minutter før",
    "15 minutes before" : "15 minutter før",
    "30 minutes before" : "30 minutter før",
    "1 hour before" : "1 time før",
    "2 hours before" : "2 timer før",
    "Custom" : "Valgfrit",
    "Audio" : "Lyd",
    "E Mail" : "E-mail",
    "Pop up" : "Pop-up",
    "sec" : "sek",
    "min" : "min.",
    "hours" : "timer",
    "days" : "dage",
    "week" : "uge",
    "before" : "før",
    "start" : "start",
    "end" : "slut",
    "Editing reminders of unknown type not supported." : "Redigeringspåmindelser, af ukendt type, er ikke understøttet.",
    "Week {number} of {year}" : "Uge {number} i {year}",
    "Successfully imported" : "Importeret succesfuldt",
    "Partially imported, 1 failure" : "Delvist importeret, 1 fejl",
    "Partially imported, {n} failures" : "Delvist importeret, {n} fejl",
    "Audio alarm" : "Lyd alarm",
    "Pop-up" : "Pop-up",
    "E-Mail" : "E-mail",
    "{type} {time} before the event starts" : "{type} {time} før begivenheden begynder",
    "{type} {time} before the event ends" : "{type} {time} før begivenheden slutter",
    "{type} {time} after the event starts" : "{type} {time} efter begivenheden begynder",
    "{type} {time} after the event ends" : "{type} {time} efter begivenheden slutter",
    "{type} at the event's start" : "{type} ved begivenhedens begyndelse",
    "{type} at the event's end" : "{type} ved begivenhedens slutning",
    "{type} at {time}" : "{type} på {time}",
    "{calendar} shared by {owner}" : "{calendar} delt af {owner}",
    "Please enter a valid WebCal-URL" : "Angiv en gyldig WebCal-URL",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Alvorlig fejl i webcal proxy. Kontakt venligst administratoren for mere information.",
    "Title of the Event" : "Titel på begivenheden",
    "starts" : "starter",
    "ends" : "slutter",
    "All day Event" : "Heldagsbegivenhed",
    "Delete" : "Slet",
    "Cancel" : "Annullér",
    "More ..." : "Mere...",
    "Create" : "Ny",
    "Update" : "Opdatér",
    "Close" : "Luk",
    "Location" : "Placering",
    "Description" : "Beskrivelse",
    "Event status" : "Begivenhedens status",
    "Visibility when sharing" : "Synlighed ved deling",
    "Export" : "Eksportér",
    "%s has published the calendar %s" : "%s har offentliggjort kalenderen %s",
    "Hello," : "Hej,",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Vi ønskede at informere dig om at %s har offentliggjort kalenderen {boldstart}%s{boldend}.",
    "Click here to access it" : "Klik her for at få adgang til den",
    "Cheers!" : "Hav en fortsat god dag.",
    "We wanted to inform you that %s has published the calendar %s." : "Vi ønskede at informere dig om at %s har offentliggjort kalenderen %s.",
    "Click on the link below to access it" : "Klik på linket under for at få adgang til den",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "På grund af en \"upstream bug\", er kalenderen, i øjeblikket, ikke i stand til at understøtte funktionen \"asset pipeline\".",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Kontakt venligst din administrator og bed om at \"asset-pipeline.enabled\" bliver slået fra.",
    "Day" : "Dag",
    "Week" : "Uge",
    "Month" : "Måned",
    "Today" : "I dag",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Nogle begivenheder i denne kalender er fejlbehæftet. Tjek venligst JS-konsollen for mere information.",
    "Share Calendar" : "Del kalender",
    "Shared" : "Delt",
    "More" : "Mere",
    "Edit" : "Redigér",
    "Link" : "Link",
    "iCal link" : "iCal link",
    "Download" : "Hent",
    "Share with users or groups" : "Del med brugere eller grupper",
    "can edit" : "kan redigere",
    "Share link" : "Del link",
    "Public access" : "Offentlig adgang",
    "Email link to person" : "E-mail link til person",
    "Send" : "Send",
    "New Calendar" : "Ny kalender",
    "Name" : "Navn",
    "New Subscription" : "Tilføj abonnement",
    "Go back" : "Gå tilbage",
    "Go forward" : "Gå frem",
    "Edit event" : "Rediger begivenhed",
    "Delete Event" : "Slet begivenhed",
    "Save Event" : "Gem begivenhed",
    "Time" : "Tid",
    "Type" : "Type",
    "Relative" : "Relative",
    "Absolute" : "Absolut",
    "Repeat" : "Gentag",
    "times every" : "gange hver",
    "Add" : "Tilføj",
    "E-Mail address of attendee" : "E-mailadresse på deltager",
    "Please add your email address in the personal settings in order to add attendees." : "Tilføj din e-mailadresse under Personlige indstillinger for at kunne invitere deltagere.",
    "from" : "fra",
    "to" : "til",
    "This event's repeating rule is not supported yet." : "Denne begivenheds gentagelsesregel understøttes ikke endnu.",
    "Support for advanced rules will be added with subsequent updates." : "Understøttelse af avancerede regler, vil blive tilføjet ved senere opdateringer.",
    "Reset repeating rule" : "Nulstil gentagelsesregel",
    "Repeat every ..." : "Gentag hver ...",
    "end repeat ..." : "stop gentagelse ...",
    "times" : "gange",
    "Import Calendars" : "Importer kalenderere",
    "Import canceled" : "Importering annulleret",
    "Analyzing calendar" : "Analyserer kalender",
    "The file contains objects incompatible with the selected calendar" : "Filen indeholder objekter som ikke er kompatible med den valgte kalender",
    "New calendar" : "Ny kalender",
    "File is empty" : "Fil er tom",
    "Import scheduled" : "Importering planlagt",
    "Subscribe & embed" : "abonner & indlejre",
    "Publish URL" : "Offentliggør URL",
    "Iframe to integrate" : "Iframe for at integrere ",
    "Settings & import" : "Indstillinger & importer",
    "Skip simple event editor" : "Spring over enkel begivenheds tekstbehandler",
    "Show week numbers" : "Vis ugenummer ",
    "Import calendar" : "Importer kalender",
    "No Calendars selected for import" : "Ingen kalendere er valgt til importering",
    "Primary CalDAV address" : "Primær CalDAV-adresse",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV-adresse"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-calendar-1.5.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/da.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalender",
    "%s has published the calendar \"%s\"" : "%s har offentliggjort kalenderen \"%s\"",
    "Too many redirects. Aborting ..." : "For mange omdirigeringer. Afbryder ...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Serveren gav os ikke adgang til kalenderen (HTTP {%s} fejl)",
    "Error connecting to remote server" : "Fejl ved forbindelse til serveren",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Fejl efter anmodning fra serveren. Dette er muligvis relateret til ikke ens certifikater",
    "Error requesting resource on remote server" : "Fejl efter anmodning fra server",
    "Individual" : "Individuelt",
    "Group" : "Gruppe",
    "Resource" : "Ressource",
    "Room" : "Lokale",
    "Unknown" : "Ukendt",
    "Required" : "Krævet",
    "Optional" : "Valgfri",
    "Does not attend" : "Deltager ikke",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Du er i en ukendt tidszone ({tz}), -sætter tiden til UTC",
    "Please create a calendar first." : "Opret venligst en kalender først",
    "New event" : "Opret begivenhed",
    "CalDAV address for clients" : "CalDAV addresse for klienter",
    "Error saving WebCal-calendar" : "Kunne ikke gemme WebCal-kalender",
    "WebDAV address for subscriptions" : "WeblDAV addresse for abonnementer",
    "EMail has been sent." : "Email afsendt",
    "There was an issue while sending your EMail." : "Der var et problem ved afsendelse af din Email.",
    "group" : "gruppe",
    "Details" : "Detaljer",
    "Attendees" : "Deltagere",
    "Reminders" : "Påmindindelser",
    "Repeating" : "Gentagende",
    "When shared show full event" : "Når delt, vis den fulde begivenhed",
    "When shared show only busy" : "Når delt, vis kun optaget",
    "When shared hide this event" : "Når delt, skjul denne begivenhed",
    "Confirmed" : "Bekræftet",
    "Tentative" : "Foreløbig prøve",
    "Cancelled" : "Annulléret",
    "Please add a title!" : "Vær venlig at tilføje en titel!",
    "Please select a calendar!" : "Vælg venligt kalender",
    "The event ends before it starts!" : "Begivenheden slutter før den starter!",
    "Global" : "Global",
    "None" : "Ingen",
    "Every day" : "Hver dag",
    "Every week" : "Hver uge",
    "Every month" : "Hver måmned",
    "Every year" : "Hvert år",
    "never" : "aldrig",
    "after" : "efter",
    "How about getting started by importing some calendars?" : "Hvad med at starte med at importere nogle kalendere?",
    "At time of event" : "På tidspunktet for begivenheden",
    "5 minutes before" : "5 minutter før",
    "10 minutes before" : "10 minutter før",
    "15 minutes before" : "15 minutter før",
    "30 minutes before" : "30 minutter før",
    "1 hour before" : "1 time før",
    "2 hours before" : "2 timer før",
    "Custom" : "Valgfrit",
    "Audio" : "Lyd",
    "E Mail" : "E-mail",
    "Pop up" : "Pop-up",
    "sec" : "sek",
    "min" : "min.",
    "hours" : "timer",
    "days" : "dage",
    "week" : "uge",
    "before" : "før",
    "start" : "start",
    "end" : "slut",
    "Editing reminders of unknown type not supported." : "Redigeringspåmindelser, af ukendt type, er ikke understøttet.",
    "Week {number} of {year}" : "Uge {number} i {year}",
    "Successfully imported" : "Importeret succesfuldt",
    "Partially imported, 1 failure" : "Delvist importeret, 1 fejl",
    "Partially imported, {n} failures" : "Delvist importeret, {n} fejl",
    "Audio alarm" : "Lyd alarm",
    "Pop-up" : "Pop-up",
    "E-Mail" : "E-mail",
    "{type} {time} before the event starts" : "{type} {time} før begivenheden begynder",
    "{type} {time} before the event ends" : "{type} {time} før begivenheden slutter",
    "{type} {time} after the event starts" : "{type} {time} efter begivenheden begynder",
    "{type} {time} after the event ends" : "{type} {time} efter begivenheden slutter",
    "{type} at the event's start" : "{type} ved begivenhedens begyndelse",
    "{type} at the event's end" : "{type} ved begivenhedens slutning",
    "{type} at {time}" : "{type} på {time}",
    "{calendar} shared by {owner}" : "{calendar} delt af {owner}",
    "Please enter a valid WebCal-URL" : "Angiv en gyldig WebCal-URL",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Alvorlig fejl i webcal proxy. Kontakt venligst administratoren for mere information.",
    "Title of the Event" : "Titel på begivenheden",
    "Starts" : "Starter",
    "Ends" : "Slutter",
    "All day Event" : "Heldagsbegivenhed",
    "Delete" : "Slet",
    "Cancel" : "Annullér",
    "More ..." : "Mere...",
    "Create" : "Ny",
    "Update" : "Opdatér",
    "Close" : "Luk",
    "Location" : "Placering",
    "Description" : "Beskrivelse",
    "Event status" : "Begivenhedens status",
    "Visibility when sharing" : "Synlighed ved deling",
    "Export" : "Eksportér",
    "%s has published the calendar %s" : "%s har offentliggjort kalenderen %s",
    "Hello," : "Hej,",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Vi ønskede at informere dig om at %s har offentliggjort kalenderen {boldstart}%s{boldend}.",
    "Click here to access it" : "Klik her for at få adgang til den",
    "Cheers!" : "Hav en fortsat god dag.",
    "We wanted to inform you that %s has published the calendar %s." : "Vi ønskede at informere dig om at %s har offentliggjort kalenderen %s.",
    "Click on the link below to access it" : "Klik på linket under for at få adgang til den",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "På grund af en \"upstream bug\", er kalenderen, i øjeblikket, ikke i stand til at understøtte funktionen \"asset pipeline\".",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Kontakt venligst din administrator og bed om at \"asset-pipeline.enabled\" bliver slået fra.",
    "Day" : "Dag",
    "Week" : "Uge",
    "Month" : "Måned",
    "Today" : "I dag",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Nogle begivenheder i denne kalender er fejlbehæftet. Tjek venligst JS-konsollen for mere information.",
    "Share Calendar" : "Del kalender",
    "Shared" : "Delt",
    "More" : "Mere",
    "Edit" : "Redigér",
    "Link" : "Link",
    "iCal link" : "iCal link",
    "Download" : "Hent",
    "Share with users or groups" : "Del med brugere eller grupper",
    "can edit" : "kan redigere",
    "Share link" : "Del link",
    "Public access" : "Offentlig adgang",
    "Email link to person" : "E-mail link til person",
    "Send" : "Send",
    "New Calendar" : "Ny kalender",
    "Name" : "Navn",
    "New Subscription" : "Tilføj abonnement",
    "Go back" : "Gå tilbage",
    "Go forward" : "Gå frem",
    "Edit event" : "Rediger begivenhed",
    "Delete Event" : "Slet begivenhed",
    "Save Event" : "Gem begivenhed",
    "Time" : "Tid",
    "Type" : "Type",
    "Relative" : "Relative",
    "Absolute" : "Absolut",
    "Repeat" : "Gentag",
    "times every" : "gange hver",
    "Add" : "Tilføj",
    "E-Mail address of attendee" : "E-mailadresse på deltager",
    "Please add your email address in the personal settings in order to add attendees." : "Tilføj din e-mailadresse under Personlige indstillinger for at kunne invitere deltagere.",
    "from" : "fra",
    "to" : "til",
    "This event's repeating rule is not supported yet." : "Denne begivenheds gentagelsesregel understøttes ikke endnu.",
    "Support for advanced rules will be added with subsequent updates." : "Understøttelse af avancerede regler, vil blive tilføjet ved senere opdateringer.",
    "Reset repeating rule" : "Nulstil gentagelsesregel",
    "Repeat every ..." : "Gentag hver ...",
    "end repeat ..." : "stop gentagelse ...",
    "times" : "gange",
    "Import Calendars" : "Importer kalenderere",
    "Import canceled" : "Importering annulleret",
    "Analyzing calendar" : "Analyserer kalender",
    "The file contains objects incompatible with the selected calendar" : "Filen indeholder objekter som ikke er kompatible med den valgte kalender",
    "New calendar" : "Ny kalender",
    "File is empty" : "Fil er tom",
    "Import scheduled" : "Importering planlagt",
    "Publish URL" : "Offentliggør URL",
    "Settings & import" : "Indstillinger & importer",
    "Skip simple event editor" : "Spring over enkel begivenheds tekstbehandler",
    "Show week numbers" : "Vis ugenummer ",
    "Import calendar" : "Importer kalender",
    "No Calendars selected for import" : "Ingen kalendere er valgt til importering",
    "Primary CalDAV address" : "Primær CalDAV-adresse",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV-adresse"
},
"nplurals=2; plural=(n != 1);");
